%% ElasticVTLN registration demo

addpath('elasticRegDemoSrc');

% load demo data
load('elasticVTLNDemo.mat');

% show data
figure(1);
subplot(3,1,1);
imagesc(tempimg'), axis xy, xlabel('frame #'), ylabel('channel #');
title('original TF representation');

subplot(3,1,2);
imagesc(refimg'), axis xy,  xlabel('frame #'), ylabel('channel #');
title('optimal values based on forced alignment');

% compute deformation
LAMBDA    = 1; % regularization weight, try, e.g., 10, 1, and 0.1 to see the effects
NUMITER   = 200; % number of iterations
% PRELAGVEC = linspace(-0.5,0.5,17); % possible values for a translational pre-registration
PRELAGVEC = [];
[u prelag Tu dev_distance] = doElasticReg( refimg,tempimg, ...
                                           LAMBDA,0,NUMITER, ...
                                           'verbose',false,'prereg',PRELAGVEC );

% visualize deformation
figure(2);
imagesc(Tu',[0.01*min(Tu(:)) max(Tu(:))]), colormap(gray), axis xy;
set(gca,'fontname','times','fontsize',10);
xlabel('frame #'), ylabel('channel #'), title('deformation field');
hold on, quiver(reshape(u(:,1),size(Tu,1),size(Tu,2))',reshape(u(:,2),size(Tu,1),size(Tu,2))',1,'linewidth',0.5), hold off

% show deformed version of original TF representation
figure(1);
subplot(3,1,3);
imagesc(Tu'), axis xy, xlabel('frame #'), ylabel('channel #');
title('deformed version of original TF representation');

% show development of distance measure
figure(3);
plot(dev_distance), xlabel('iteration #'), ylabel('distance relative to initial distance');
title('Evolution of distance measure during iterative solution');

